@@ -17,7 +17,6 @@
 */
 
 #include "mainwindow.h"
-#include "mainwindow.moc"
 
 #include "ui_configure_step_general.h"
 
@@ -35,32 +34,32 @@
 #include <stepcore/solver.h>
 #include <stepcore/collisionsolver.h>
 
-#include <KAction>
 #include <KActionCollection>
 #include <KStandardAction>
 #include <KRecentFilesAction>
-#include <KApplication>
 #include <KMessageBox>
 #include <KFileDialog>
-#include <KTemporaryFile>
 #include <KConfigDialog>
 #include <KStandardDirs>
 #include <KStatusBar>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KConfig>
 #include <KToolBarPopupAction>
 
 #include <KIO/NetAccess>
 #include <knewstuff3/downloaddialog.h>
 
+#include <QAction>
+#include <QTemporaryFile>
+#include <QIcon>
 #include <QFile>
 #include <QGraphicsView>
-#include <QItemSelectionModel>
-#include <QHBoxLayout>
 #include <QMenu>
+#include <QKeySequence>
 
 #include <cstdlib>
 #include <ctime>
+#include <QStandardPaths>
 
 MainWindow::MainWindow()
 {
@@ -108,13 +107,13 @@ MainWindow::MainWindow()
     connect(worldModel->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
                                  this, SLOT(worldSelectionChanged()));
     connect(itemPalette, SIGNAL(beginAddItem(const QString&)),
-                                 worldScene, SLOT(beginAddItem(const QString&)));
-    connect(worldScene, SIGNAL(endAddItem(const QString&, bool)),
-                                 itemPalette, SLOT(endAddItem(const QString&, bool)));
-    connect(worldScene, SIGNAL(linkActivated(const KUrl&)),
-                                 infoBrowser, SLOT(openUrl(const KUrl&)));
-    connect(worldScene, SIGNAL(endAddItem(QString, bool)),
-            this, SLOT(worldSelectionChanged()));
+	    worldScene,  SLOT(beginAddItem(const QString&)));
+    connect(worldScene,  SIGNAL(endAddItem(const QString&, bool)),
+	    itemPalette, SLOT(endAddItem(const QString&, bool)));
+    connect(worldScene,  SIGNAL(linkActivated(const QUrl&)),
+	    infoBrowser, SLOT(openUrl(const QUrl&)));
+    connect(worldScene,  SIGNAL(endAddItem(QString, bool)),
+            this,        SLOT(worldSelectionChanged()));
     
 
     setupActions();
@@ -139,36 +138,37 @@ void MainWindow::setupActions()
     KStandardAction::save(this, SLOT(saveFile()), actionCollection());
     KStandardAction::saveAs(this, SLOT(saveFileAs()), actionCollection());
     KStandardAction::quit(this, SLOT(close()), actionCollection());
-    actionRecentFiles = KStandardAction::openRecent(this, SLOT(openFile(const KUrl&)), actionCollection());
+    actionRecentFiles = KStandardAction::openRecent(this, SLOT(openFile(const QUrl&)),
+						    actionCollection());
 
     KConfig* config = new KConfig("steprc");
     actionRecentFiles->loadEntries(config->group("RecentFiles"));
     delete config;
 
-    KAction* actionOpenTutorial = actionCollection()->add<KAction>(
+    QAction * actionOpenTutorial = actionCollection()->add<QAction>(
                 "file_tutorial_open", this, SLOT(openTutorial()));
     actionOpenTutorial->setText(i18n("&Open Tutorial..."));
-    actionOpenTutorial->setIcon(KIcon("document-open"));
+    actionOpenTutorial->setIcon(QIcon::fromTheme("document-open"));
 
-    KAction* actionOpenExample = actionCollection()->add<KAction>(
+    QAction * actionOpenExample = actionCollection()->add<QAction>(
                 "file_example_open", this, SLOT(openExample()));
     actionOpenExample->setText(i18n("&Open Example..."));
-    actionOpenExample->setIcon(KIcon("document-open"));
+    actionOpenExample->setIcon(QIcon::fromTheme("document-open"));
 
-    KAction* actionOpenLocalExample = actionCollection()->add<KAction>(
+    QAction * actionOpenLocalExample = actionCollection()->add<QAction>(
                 "file_example_openlocal", this, SLOT(openLocalExample()));
     actionOpenLocalExample->setText(i18n("Open Down&loaded Example..."));
-    actionOpenLocalExample->setIcon(KIcon("document-open"));
+    actionOpenLocalExample->setIcon(QIcon::fromTheme("document-open"));
 
-    KAction* actionUploadExample = actionCollection()->add<KAction>(
+    QAction * actionUploadExample = actionCollection()->add<QAction>(
                 "file_example_upload", this, SLOT(uploadExample()));
     actionUploadExample->setText(i18n("Share C&urrent Experiment..."));
-    actionUploadExample->setIcon(KIcon("get-hot-new-stuff"));
+    actionUploadExample->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
 
-    KAction* actionDownloadExamples = actionCollection()->add<KAction>(
+    QAction * actionDownloadExamples = actionCollection()->add<QAction>(
                 "file_example_download", this, SLOT(downloadExamples()));
     actionDownloadExamples->setText(i18n("&Download New Experiments..."));
-    actionDownloadExamples->setIcon(KIcon("get-hot-new-stuff"));
+    actionDownloadExamples->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
 
     /* Edit menu */
     actionRedo = KStandardAction::redo(worldModel->undoStack(), SLOT(redo()), actionCollection());
@@ -195,10 +195,10 @@ void MainWindow::setupActions()
     connect(worldModel->clipboard(), SIGNAL(canPasteChanged(bool)),
             actionPaste, SLOT(setEnabled(bool)));
 
-    actionDelete = actionCollection()->add<KAction>("edit_delete", worldModel, SLOT(deleteSelectedItems()));
+    actionDelete = actionCollection()->add<QAction>("edit_delete", worldModel, SLOT(deleteSelectedItems()));
     actionDelete->setText(i18n("&Delete"));
-    actionDelete->setIcon(KIcon("edit-delete"));
-    actionDelete->setShortcut(KShortcut(Qt::Key_Delete));
+    actionDelete->setIcon(QIcon::fromTheme("edit-delete"));
+    actionDelete->setShortcut(QKeySequence(Qt::Key_Delete));
     actionDelete->setEnabled(false);
 
     /* Simulation menu */
@@ -206,7 +206,7 @@ void MainWindow::setupActions()
     QActionGroup* runSpeedGroup = new QActionGroup(this);
 
     // The run action collection, this is used in the toolbar to create a dropdown menu on the run button
-    runSpeedAction = new KToolBarPopupAction(KIcon("media-playback-start"), i18n("&Run"), this);
+    runSpeedAction = new KToolBarPopupAction(QIcon::fromTheme("media-playback-start"), i18n("&Run"), this);
     connect(runSpeedAction, SIGNAL(triggered()), 
             this, SLOT(simulationStartStop()));
     QMenu* runSpeedActionMenu = runSpeedAction->menu();
@@ -214,7 +214,7 @@ void MainWindow::setupActions()
     runSpeedActionMenu->setStatusTip(i18n("Execute the program"));
     runSpeedActionMenu->setWhatsThis(i18n("Run: Execute the program"));
 
-    fullSpeedAct = new KAction(i18nc("@option:radio", "1x Speed"), this);
+    fullSpeedAct = new QAction(i18nc("@option:radio", "1x Speed"), this);
     actionCollection()->addAction("full_speed", fullSpeedAct );
     fullSpeedAct->setCheckable(true);
     fullSpeedAct->setChecked(true);
@@ -222,28 +222,28 @@ void MainWindow::setupActions()
     runSpeedGroup->addAction(fullSpeedAct);
     runSpeedActionMenu->addAction(fullSpeedAct);
 	
-    slowSpeedAct = new KAction(i18nc("@option:radio choose the slow speed", "2x Speed"), this);
+    slowSpeedAct = new QAction(i18nc("@option:radio choose the slow speed", "2x Speed"), this);
     actionCollection()->addAction("slow_speed", slowSpeedAct );
     slowSpeedAct->setCheckable(true);
     connect(slowSpeedAct, SIGNAL(triggered()), this, SLOT(setSlowSpeed()));
     runSpeedGroup->addAction(slowSpeedAct);
     runSpeedActionMenu->addAction(slowSpeedAct);
 
-    slowerSpeedAct = new KAction(i18nc("@option:radio", "4x Speed"), this);
+    slowerSpeedAct = new QAction(i18nc("@option:radio", "4x Speed"), this);
     actionCollection()->addAction("slower_speed", slowerSpeedAct );
     slowerSpeedAct->setCheckable(true);
     connect(slowerSpeedAct, SIGNAL(triggered()), this, SLOT(setSlowerSpeed()));
     runSpeedGroup->addAction(slowerSpeedAct);
     runSpeedActionMenu->addAction(slowerSpeedAct);
 
-    slowestSpeedAct = new KAction(i18nc("@option:radio", "8x Speed"), this);
+    slowestSpeedAct = new QAction(i18nc("@option:radio", "8x Speed"), this);
     actionCollection()->addAction("slowest_speed", slowestSpeedAct );
     slowestSpeedAct->setCheckable(true);
     connect(slowestSpeedAct, SIGNAL(triggered()), this, SLOT(setSlowestSpeed()));
     runSpeedGroup->addAction(slowestSpeedAct);
     runSpeedActionMenu->addAction(slowestSpeedAct);
 
-    stepSpeedAct = new KAction(i18nc("@option:radio", "16x Speed"), this);
+    stepSpeedAct = new QAction(i18nc("@option:radio", "16x Speed"), this);
     actionCollection()->addAction("step_speed", stepSpeedAct );
     stepSpeedAct->setCheckable(true);
     connect(stepSpeedAct, SIGNAL(triggered()), this, SLOT(setStepSpeed()));
@@ -272,8 +272,10 @@ void MainWindow::setupActions()
 void MainWindow::updateCaption()
 {
     QString shownName;
-    if(currentFileUrl.isEmpty()) shownName = i18nc("filename", "untitled.step"); //Fixme if needed
-    else shownName = currentFileUrl.pathOrUrl(); //QFileInfo(currentFileName).fileName();
+    if (currentFileUrl.isEmpty())
+	shownName = i18nc("filename", "untitled.step"); //Fixme if needed
+    else
+	shownName = currentFileUrl.url(QUrl::PreferLocalFile); //QFileInfo(currentFileName).fileName();
     setCaption(shownName, !worldModel->undoStack()->isClean());
 }
 
@@ -295,7 +297,7 @@ bool MainWindow::newFile()
     worldModel->clearWorld();
     worldGraphicsView->actualSize();
     worldGraphicsView->centerOn(0,0);
-    currentFileUrl = KUrl();
+    currentFileUrl = QUrl();
     updateCaption();
     undoBrowser->setEmptyLabel(i18n("<new file>"));
     undoBrowser->setCurrentFileUrl(currentFileUrl);
@@ -304,12 +306,12 @@ bool MainWindow::newFile()
     return true;
 }
 
-bool MainWindow::openFile(const KUrl& url, const KUrl& startUrl)
+bool MainWindow::openFile(const QUrl& url, const QUrl& startUrl)
 {
     if(worldModel->isSimulationActive()) simulationStop();
     if(!maybeSave()) return false;
 
-    KUrl fileUrl = url;
+    QUrl fileUrl = url;
     if(fileUrl.isEmpty()) {
         fileUrl = KFileDialog::getOpenUrl(startUrl, i18n("*.step|Step files (*.step)"), this); //is this i18n legal?
         if(fileUrl.isEmpty()) return false;
@@ -332,7 +334,7 @@ bool MainWindow::openFile(const KUrl& url, const KUrl& startUrl)
     }
     
     if(!worldModel->loadXml(&file)) {
-        KMessageBox::sorry(this, i18n("Cannot parse file '%1': %2", fileUrl.pathOrUrl(),
+        KMessageBox::sorry(this, i18n("Cannot parse file '%1': %2", fileUrl.url(QUrl::PreferLocalFile),
                                                     worldModel->errorString()));
         KIO::NetAccess::removeTempFile(tmpFileName);
         return false;
@@ -350,17 +352,18 @@ bool MainWindow::openFile(const KUrl& url, const KUrl& startUrl)
     return true;
 }
 
-bool MainWindow::saveFileAs(const KUrl& url, const KUrl& startUrl)
+bool MainWindow::saveFileAs(const QUrl& url, const QUrl& startUrl)
 {
     if(worldModel->isSimulationActive()) simulationStop();
-    KUrl fileUrl = url;
+    QUrl fileUrl = url;
     if(fileUrl.isEmpty()) {
         fileUrl = KFileDialog::getSaveUrl(startUrl.isEmpty() ? currentFileUrl : startUrl,
                                              i18n("*.step|Step files (*.step)"), this);
         if(fileUrl.isEmpty()) return false;
         else if(KIO::NetAccess::exists(fileUrl, KIO::NetAccess::DestinationSide, this)) {
             int ret = KMessageBox::warningContinueCancel(this,
-                        i18n( "The file \"%1\" already exists. Do you wish to overwrite it?", fileUrl.pathOrUrl()),
+                        i18n("The file \"%1\" already exists. Do you wish to overwrite it?",
+			     fileUrl.url(QUrl::PreferLocalFile)),
                         i18n("Warning - Step"), KStandardGuiItem::overwrite());
             if(ret != KMessageBox::Continue) return false;
         }
@@ -370,8 +373,9 @@ bool MainWindow::saveFileAs(const KUrl& url, const KUrl& startUrl)
     QFile* file;
 
     if(!local) {
-        file = new KTemporaryFile();
-        static_cast<KTemporaryFile*>(file)->setAutoRemove(true);
+        QTemporaryFile *tempFile = new QTemporaryFile();
+        tempFile->setAutoRemove(true);
+	file = tempFile;
     } else {
         file = new QFile(fileUrl.path());
     }
@@ -383,8 +387,9 @@ bool MainWindow::saveFileAs(const KUrl& url, const KUrl& startUrl)
     }
     
     if(!worldModel->saveXml(file)) {
-        KMessageBox::sorry(this, i18n("Cannot save file '%1': %2", fileUrl.pathOrUrl(),
-                                        worldModel->errorString()));
+        KMessageBox::sorry(this, i18n("Cannot save file '%1': %2",
+				      fileUrl.url(QUrl::PreferLocalFile),
+				      worldModel->errorString()));
         delete file;
         return false;
     }
@@ -427,11 +432,13 @@ bool MainWindow::maybeSave()
 void MainWindow::openTutorial()
 {
     // XXX: need to be redone
-    QStringList dirs = KGlobal::dirs()->findDirs("appdata", "tutorials");
-    QString localDir = KStandardDirs::locateLocal("appdata", "");
-    foreach(const QString &dir, dirs) {
-        if(!dir.startsWith(localDir)) {
-            openFile(KUrl(), dir);
+    //qDebug() << "inside MainWindow::openTutorial()";
+    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, "tutorials", QStandardPaths::LocateDirectory);
+    QString localDir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/');
+    foreach(const QString &dirName, dirs) {
+        //qDebug() << "dirName: " << dirName;
+        if(!dirName.startsWith(localDir)) {
+	    openFile(QUrl(), QUrl::fromLocalFile(dirName));
             return;
         }
     }
@@ -439,12 +446,13 @@ void MainWindow::openTutorial()
 
 void MainWindow::openExample()
 {
+    //qDebug() << "inside MainWindow::openExample()";
     // XXX: need to be redone
-    QStringList dirs = KGlobal::dirs()->findDirs("appdata", "examples");
-    QString localDir = KStandardDirs::locateLocal("appdata", "");
-    foreach(const QString &dir, dirs) {
-        if(!dir.startsWith(localDir)) {
-            openFile(KUrl(), dir);
+    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, "examples", QStandardPaths::LocateDirectory);
+    QString localDir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/');
+    foreach(const QString &dirName, dirs) {
+        if(!dirName.startsWith(localDir)) {
+            openFile(QUrl(), QUrl::fromLocalFile(dirName));
             return;
         }
     }
@@ -453,10 +461,10 @@ void MainWindow::openExample()
 void MainWindow::openLocalExample()
 {
     // XXX: need to be redone
-    QString dir = KStandardDirs::locateLocal("appdata", "examples");
+    QString dir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/examples";
     if(dir.isEmpty()) return;
     KStandardDirs::makeDir(dir);
-    openFile(KUrl(), dir);
+    openFile(QUrl(), QUrl::fromLocalFile(dir));
 }
 
 void MainWindow::uploadExample()
@@ -483,6 +491,7 @@ void MainWindow::uploadExample()
 
 void MainWindow::downloadExamples()
 {
+    //qDebug() << "inside MainWindow::downloadExamples()";
     KNS3::DownloadDialog dialog("step.knsrc", this);
     dialog.exec();
 }
@@ -496,7 +505,7 @@ void MainWindow::simulationStartStop()
 void MainWindow::simulationStart()
 {
     runSpeedAction->setIconText(i18n("&Stop"));
-    runSpeedAction->setIcon(KIcon("media-playback-stop"));
+    runSpeedAction->setIcon(QIcon::fromTheme("media-playback-stop"));
 
     undoBrowser->setUndoEnabled(false);
     actionUndo->setEnabled(false);
@@ -506,7 +515,7 @@ void MainWindow::simulationStart()
 void MainWindow::simulationStopped(int result)
 {
     runSpeedAction->setIconText(i18n("&Simulate"));
-    runSpeedAction->setIcon(KIcon("media-playback-start"));
+    runSpeedAction->setIcon(QIcon::fromTheme("media-playback-start"));
 
     undoBrowser->setUndoEnabled(true);
     if(result == StepCore::Solver::ToleranceError) {
